resumptionTime property
The time by which an employee is considered "In-time". If null, status will always be "In-time".
Implementation
final TimeOfDay? resumptionTime;
The time by which an employee is considered "In-time". If null, status will always be "In-time".
final TimeOfDay? resumptionTime;