ClockInResult class

The final result of the clock-in process.

Constructors

ClockInResult({String? image, DateTime? clockInTime, bool isLate = false, double? latitude, double? longitude, LivenessException? exception})

Properties

clockInTime DateTime?
The timestamp when the clock-in was successful.
final
exception LivenessException?
Any exception that occurred during the process.
final
hashCode int
The hash code for this object.
no setterinherited
image String?
The Base64 encoded image string captured during clock-in.
final
isLate bool
Whether the user was late based on the config's resumption time.
final
isSuccess bool
Returns true if the clock-in was successful.
no setter
latitude double?
The latitude where the clock-in occurred.
final
longitude double?
The longitude where the clock-in occurred.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited