CustomFace class

A platform-agnostic representation of a detected face.

Constructors

CustomFace({int? trackingId, double? smilingProbability, double? headEulerAngleX, double? headEulerAngleY, double? leftEyeOpenProbability, double? rightEyeOpenProbability, required Rect boundingBox, List<Vector3>? landmarks})

Properties

boundingBox Rect
final
hashCode int
The hash code for this object.
no setterinherited
headEulerAngleX double?
final
headEulerAngleY double?
final
landmarks List<Vector3>?
final
leftEyeOpenProbability double?
final
rightEyeOpenProbability double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smilingProbability double?
final
trackingId int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited