ClockInConfig class

Configuration for the Clock In process.

Constructors

ClockInConfig({Color primaryColor = const Color(0xFF2ECC71), Color successColor = const Color(0xFF2ECC71), Color lateColor = const Color(0xFFE74C3C), TimeOfDay? resumptionTime, double? targetLatitude, double? targetLongitude, double locationRadius = 200.0, bool requireLiveness = true, String? title, String? successTitle, String? successMessage, IconData? instructionIcon, bool skipLocation = false, Future<ClockInProcessResult> onProcess(Map<String, dynamic> data)?, ClockInType type = ClockInType.inTime})

Properties

displaySuccessMessage String
Helper to get the success message based on type if not explicitly provided.
no setter
displaySuccessTitle String
Helper to get the success title based on type if not explicitly provided.
no setter
displayTimeLabel String
Helper to get the time label based on type.
no setter
displayTitle String
Helper to get the display title based on type if not explicitly provided.
no setter
hashCode int
The hash code for this object.
no setterinherited
instructionIcon IconData?
The icon to show next to instructions. If null, an animated star will be shown.
final
lateColor Color
The color used to indicate a "Late" status.
final
locationRadius double
The allowed radius in meters from the target location.
final
onProcess Future<ClockInProcessResult> Function(Map<String, dynamic> data)?
Optional callback to process the clock-in data on the app side. If provided, this will be called instead of/in addition to the endpointUrl.
final
primaryColor Color
The primary color used for buttons, progress rings, and accents.
final
requireLiveness bool
Whether to require face liveness checks during clock in.
final
resumptionTime TimeOfDay?
The time by which an employee is considered "In-time". If null, status will always be "In-time".
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipLocation bool
Whether to skip the location verification step.
final
successColor Color
The color used to indicate a successful "In-time" status.
final
successMessage String?
The message shown on the success screen.
final
successTitle String?
The title shown on the success screen.
final
targetLatitude double?
The target location for geofencing.
final
targetLongitude double?
The target location for geofencing.
final
title String?
The main title at the top of the screen.
final
type ClockInType
Whether this is a Clock In or Clock Out operation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited