ClockInProcessResult class
The result of the app-side processing of a clock-in event.
Constructors
- ClockInProcessResult({required bool success, String? errorMessage})
- ClockInProcessResult.failure(String message)
-
Factory constructor for a failed result.
factory
- ClockInProcessResult.success()
-
Factory constructor for a successful result.
factory
Properties
- errorMessage → String?
-
A message to display to the user if the processing failed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether the processing was successful.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited